@@ -48,10 +48,13 @@ class CutMix(BaseImageAugmentationLayer):
         self.alpha = alpha
         self.seed = seed
 
-    @staticmethod
-    def _sample_from_beta(alpha, beta, shape):
-        sample_alpha = tf.random.gamma(shape, 1.0, beta=alpha)
-        sample_beta = tf.random.gamma(shape, 1.0, beta=beta)
+    def _sample_from_beta(self, alpha, beta, shape):
+        sample_alpha = tf.random.gamma(
+            shape, 1.0, beta=alpha, seed=self._random_generator.make_legacy_seed()
+        )
+        sample_beta = tf.random.gamma(
+            shape, 1.0, beta=beta, seed=self._random_generator.make_legacy_seed()
+        )
         return sample_alpha / (sample_alpha + sample_beta)
 
     def _batch_augment(self, inputs):
@@ -86,7 +89,7 @@ class CutMix(BaseImageAugmentationLayer):
         )
 
         permutation_order = tf.random.shuffle(tf.range(0, batch_size), seed=self.seed)
-        lambda_sample = CutMix._sample_from_beta(self.alpha, self.alpha, (batch_size,))
+        lambda_sample = self._sample_from_beta(self.alpha, self.alpha, (batch_size,))
 
         ratio = tf.math.sqrt(1 - lambda_sample)
 
