@@ -54,7 +54,7 @@ class RandomColorDegeneration(BaseImageAugmentationLayer):
         )
         self.seed = seed
 
-    def get_random_transformation(self, image=None, label=None, bounding_boxes=None):
+    def get_random_transformation(self, **kwargs):
         return self.factor()
 
     def augment_image(self, image, transformation=None, **kwargs):
