@@ -21,7 +21,7 @@ from keras_cv.metrics.coco import COCOMeanAveragePrecision
 
 SAMPLE_FILE = os.path.dirname(os.path.abspath(__file__)) + "/sample_boxes.npz"
 
-delta = 0.05
+delta = 0.04
 
 
 class MeanAveragePrecisionTest(tf.test.TestCase):
@@ -44,7 +44,10 @@ class MeanAveragePrecisionTest(tf.test.TestCase):
 
         # Area range all
         mean_average_precision = COCOMeanAveragePrecision(
-            class_ids=categories + [1000], max_detections=100, num_buckets=1000
+            bounding_box_format="xyxy",
+            class_ids=categories + [1000],
+            max_detections=100,
+            num_buckets=1000,
         )
 
         mean_average_precision.update_state(y_true, y_pred)
@@ -55,6 +58,7 @@ class MeanAveragePrecisionTest(tf.test.TestCase):
         y_true, y_pred, categories = load_samples(SAMPLE_FILE)
 
         mean_average_precision = COCOMeanAveragePrecision(
+            bounding_box_format="xyxy",
             class_ids=categories + [1000],
             iou_thresholds=[0.5],
             max_detections=100,
@@ -68,6 +72,7 @@ class MeanAveragePrecisionTest(tf.test.TestCase):
         y_true, y_pred, categories = load_samples(SAMPLE_FILE)
 
         mean_average_precision = COCOMeanAveragePrecision(
+            bounding_box_format="xyxy",
             class_ids=categories + [1000],
             iou_thresholds=[0.75],
             max_detections=100,
@@ -81,6 +86,7 @@ class MeanAveragePrecisionTest(tf.test.TestCase):
         y_true, y_pred, categories = load_samples(SAMPLE_FILE)
 
         mean_average_precision = COCOMeanAveragePrecision(
+            bounding_box_format="xyxy",
             class_ids=categories + [1000],
             max_detections=100,
             area_range=(32**2, 96**2),
@@ -94,6 +100,7 @@ class MeanAveragePrecisionTest(tf.test.TestCase):
         y_true, y_pred, categories = load_samples(SAMPLE_FILE)
 
         mean_average_precision = COCOMeanAveragePrecision(
+            bounding_box_format="xyxy",
             class_ids=categories + [1000],
             max_detections=100,
             area_range=(96**2, 1e5**2),
@@ -103,20 +110,19 @@ class MeanAveragePrecisionTest(tf.test.TestCase):
         result = mean_average_precision.result().numpy()
         self.assertAlmostEqual(result, 0.610, delta=delta)
 
-    # TODO(lukewood): re-enable after performance testing
-    # def test_mean_average_precision_correctness_small(self):
-    #     y_true, y_pred, categories = load_samples(SAMPLE_FILE)
-    #
-    #     mean_average_precision = COCOMeanAveragePrecision(
-    #         class_ids=categories + [1000],
-    #         max_detections=100,
-    #         area_range=(0, 32**2),
-    #     )
-    #
-    #     mean_average_precision.update_state(y_true, y_pred)
-    #     result = mean_average_precision.result().numpy()
-    #     self.assertAlmostEqual(result, 0.604, delta=delta)
-    #
+    def test_mean_average_precision_correctness_small(self):
+        y_true, y_pred, categories = load_samples(SAMPLE_FILE)
+
+        mean_average_precision = COCOMeanAveragePrecision(
+            bounding_box_format="xyxy",
+            class_ids=categories + [1000],
+            max_detections=100,
+            area_range=(0, 32**2),
+        )
+
+        mean_average_precision.update_state(y_true, y_pred)
+        result = mean_average_precision.result().numpy()
+        self.assertAlmostEqual(result, 0.604, delta=delta)
 
 
 def load_samples(fname):
@@ -124,8 +130,8 @@ def load_samples(fname):
     y_true = npzfile["arr_0"].astype(np.float32)
     y_pred = npzfile["arr_1"].astype(np.float32)
 
-    y_true = bounding_box.convert_to_corners(y_true, format="coco")
-    y_pred = bounding_box.convert_to_corners(y_pred, format="coco")
+    y_true = bounding_box.convert_format(y_true, source="xyWH", target="xyxy")
+    y_pred = bounding_box.convert_format(y_pred, source="xyWH", target="xyxy")
 
     categories = set(int(x) for x in y_true[:, :, 4].numpy().flatten())
     categories = [x for x in categories if x != -1]
