@@ -29,6 +29,8 @@ class COCORecall(keras.metrics.Metric):
         class_ids: The class IDs to evaluate the metric for.  To evaluate for
             all classes in over a set of sequentially labelled classes, pass
             `range(num_classes)`.
+        bounding_box_format: Format of the incoming bounding boxes.  Supported values
+            are "xywh", "center_xywh", "xyxy".
         iou_thresholds: IoU thresholds over which to evaluate the recall.  Must
             be a tuple of floats, defaults to [0.5:0.05:0.95].
         area_range: area range to constrict the considered bounding boxes in
@@ -58,6 +60,7 @@ class COCORecall(keras.metrics.Metric):
 
     ```python
     coco_recall = keras_cv.metrics.COCORecall(
+        bounding_box_format='xyxy',
         max_detections=100,
         class_ids=[1]
     )
@@ -75,17 +78,19 @@ class COCORecall(keras.metrics.Metric):
     def __init__(
         self,
         class_ids,
+        bounding_box_format,
         iou_thresholds=None,
         area_range=None,
         max_detections=100,
-        **kwargs
+        **kwargs,
     ):
         super().__init__(**kwargs)
         # Initialize parameter values
+        self.bounding_box_format = bounding_box_format
         iou_thresholds = iou_thresholds or [x / 100.0 for x in range(50, 100, 5)]
 
         self.iou_thresholds = iou_thresholds
-        self.class_ids = class_ids
+        self.class_ids = list(class_ids)
         self.area_range = area_range
         self.max_detections = max_detections
 
@@ -93,6 +98,11 @@ class COCORecall(keras.metrics.Metric):
         num_thresholds = len(iou_thresholds)
         num_categories = len(class_ids)
 
+        if any([c < 0 for c in class_ids]):
+            raise ValueError(
+                "class_ids must be positive.  Got " f"class_ids={class_ids}"
+            )
+
         self.true_positives = self.add_weight(
             name="true_positives",
             shape=(num_thresholds, num_categories),
@@ -133,6 +143,21 @@ class COCORecall(keras.metrics.Metric):
         if isinstance(y_pred, tf.RaggedTensor):
             y_pred = y_pred.to_tensor(default_value=-1)
 
+        y_true = bounding_box.convert_format(
+            y_true,
+            source=self.bounding_box_format,
+            target="xyxy",
+            dtype=self.compute_dtype,
+        )
+        y_pred = bounding_box.convert_format(
+            y_pred,
+            source=self.bounding_box_format,
+            target="xyxy",
+            dtype=self.compute_dtype,
+        )
+
+        y_pred = utils.sort_bounding_boxes(y_pred, axis=bounding_box.XYXY.CONFIDENCE)
+
         num_images = tf.shape(y_true)[0]
 
         iou_thresholds = tf.constant(self.iou_thresholds, dtype=tf.float32)
@@ -141,7 +166,6 @@ class COCORecall(keras.metrics.Metric):
         num_thresholds = tf.shape(iou_thresholds)[0]
         num_categories = tf.shape(class_ids)[0]
 
-        # Sort by bounding_box.CONFIDENCE to make maxDetections easy to compute.
         true_positives_update = tf.zeros_like(self.true_positives)
         ground_truth_boxes_update = tf.zeros_like(self.ground_truth_boxes)
 
@@ -161,7 +185,7 @@ class COCORecall(keras.metrics.Metric):
                 category = class_ids[k_i]
 
                 category_filtered_y_pred = utils.filter_boxes(
-                    y_pred_for_image, value=category, axis=bounding_box.CLASS
+                    y_pred_for_image, value=category, axis=bounding_box.XYXY.CLASS
                 )
 
                 detections = category_filtered_y_pred
@@ -169,7 +193,7 @@ class COCORecall(keras.metrics.Metric):
                     detections = category_filtered_y_pred[: self.max_detections]
 
                 ground_truths = utils.filter_boxes(
-                    y_true_for_image, value=category, axis=bounding_box.CLASS
+                    y_true_for_image, value=category, axis=bounding_box.XYXY.CLASS
                 )
 
                 ious = iou_lib.compute_ious_for_image(ground_truths, detections)
@@ -220,6 +244,7 @@ class COCORecall(keras.metrics.Metric):
         config.update(
             {
                 "class_ids": self.class_ids,
+                "bounding_box_format": self.bounding_box_format,
                 "iou_thresholds": self.iou_thresholds,
                 "area_range": self.area_range,
                 "max_detections": self.max_detections,
