@@ -27,6 +27,7 @@ class COCORecallTest(tf.test.TestCase):
 
         recall = COCORecall(
             max_detections=100,
+            bounding_box_format="xyxy",
             class_ids=[1],
             area_range=(0, 64**2),
         )
@@ -43,7 +44,12 @@ class COCORecallTest(tf.test.TestCase):
         self.assertAllEqual(recall.result(), 1.0)
 
     def test_ragged_tensor_support(self):
-        recall = COCORecall(max_detections=100, class_ids=[1], area_range=(0, 64**2))
+        recall = COCORecall(
+            max_detections=100,
+            bounding_box_format="xyxy",
+            class_ids=[1],
+            area_range=(0, 64**2),
+        )
 
         # These would match if they were in the area range
         y_true = tf.ragged.stack(
@@ -67,14 +73,17 @@ class COCORecallTest(tf.test.TestCase):
     def test_merge_state(self):
         y_true = tf.constant([[[0, 0, 100, 100, 1]]], dtype=tf.float32)
         y_pred = tf.constant([[[0, 50, 100, 150, 1, 1.0]]], dtype=tf.float32)
+        y_pred_match = tf.constant([[[0, 0, 100, 100, 1, 1.0]]], dtype=tf.float32)
 
         m1 = COCORecall(
+            bounding_box_format="xyxy",
             iou_thresholds=[0.95],
             class_ids=[1],
             area_range=(0, 100000**2),
             max_detections=1,
         )
         m2 = COCORecall(
+            bounding_box_format="xyxy",
             iou_thresholds=[0.95],
             class_ids=[1],
             area_range=(0, 100000**2),
@@ -82,10 +91,12 @@ class COCORecallTest(tf.test.TestCase):
         )
 
         m1.update_state(y_true, y_pred)
-        m1.update_state(y_true, y_true)
+        m1.update_state(y_true, y_pred_match)
+
         m2.update_state(y_true, y_pred)
 
         metric_result = COCORecall(
+            bounding_box_format="xyxy",
             iou_thresholds=[0.95],
             class_ids=[1],
             area_range=(0, 100000**2),
@@ -99,6 +110,7 @@ class COCORecallTest(tf.test.TestCase):
 
     def test_recall_area_range_filtering(self):
         recall = COCORecall(
+            bounding_box_format="xyxy",
             max_detections=100,
             class_ids=[1],
             area_range=(32**2, 64**2),
@@ -115,7 +127,10 @@ class COCORecallTest(tf.test.TestCase):
 
     def test_missing_categories(self):
         recall = COCORecall(
-            max_detections=100, class_ids=[1, 2, 3], area_range=(0, 1e9**2)
+            bounding_box_format="xyxy",
+            max_detections=100,
+            class_ids=[1, 2, 3],
+            area_range=(0, 1e9**2),
         )
         t = len(recall.iou_thresholds)
         k = len(recall.class_ids)
@@ -134,7 +149,12 @@ class COCORecallTest(tf.test.TestCase):
         self.assertEqual(recall.result(), 0.5)
 
     def test_recall_direct_assignment(self):
-        recall = COCORecall(max_detections=100, class_ids=[1], area_range=(0, 1e9**2))
+        recall = COCORecall(
+            bounding_box_format="xyxy",
+            max_detections=100,
+            class_ids=[1],
+            area_range=(0, 1e9**2),
+        )
         t = len(recall.iou_thresholds)
         k = len(recall.class_ids)
 
@@ -146,15 +166,14 @@ class COCORecallTest(tf.test.TestCase):
         self.assertEqual(recall.result(), 0.5)
 
     def test_max_detections_one_third(self):
-        recall = COCORecall(max_detections=1, class_ids=[1], area_range=(0, 1e9**2))
+        recall = COCORecall(
+            bounding_box_format="xyxy",
+            max_detections=1,
+            class_ids=[1],
+            area_range=(0, 1e9**2),
+        )
         y_true = np.array(
-            [
-                [
-                    [0, 0, 100, 100, 1],
-                    [100, 100, 200, 200, 1],
-                    [300, 300, 400, 400, 1],
-                ]
-            ]
+            [[[0, 0, 100, 100, 1], [100, 100, 200, 200, 1], [300, 300, 400, 400, 1]]]
         ).astype(np.float32)
         y_pred = np.concatenate([y_true, np.ones((1, 3, 1))], axis=-1).astype(
             np.float32
@@ -165,15 +184,14 @@ class COCORecallTest(tf.test.TestCase):
         self.assertAlmostEqual(recall.result().numpy(), 1 / 3)
 
     def test_max_detections(self):
-        recall = COCORecall(max_detections=3, class_ids=[1], area_range=(0, 1e9**2))
+        recall = COCORecall(
+            bounding_box_format="xyxy",
+            max_detections=3,
+            class_ids=[1],
+            area_range=(0, 1e9**2),
+        )
         y_true = np.array(
-            [
-                [
-                    [0, 0, 100, 100, 1],
-                    [100, 100, 200, 200, 1],
-                    [300, 300, 400, 400, 1],
-                ]
-            ]
+            [[[0, 0, 100, 100, 1], [100, 100, 200, 200, 1], [300, 300, 400, 400, 1]]]
         ).astype(np.float32)
         y_pred = np.concatenate([y_true, np.ones((1, 3, 1))], axis=-1).astype(
             np.float32
@@ -185,7 +203,12 @@ class COCORecallTest(tf.test.TestCase):
         self.assertAlmostEqual(recall.result().numpy(), 1.0)
 
     def test_recall_direct_assignment_one_third(self):
-        recall = COCORecall(max_detections=100, class_ids=[1], area_range=(0, 1e9**2))
+        recall = COCORecall(
+            bounding_box_format="xyxy",
+            max_detections=100,
+            class_ids=[1],
+            area_range=(0, 1e9**2),
+        )
         t = len(recall.iou_thresholds)
         k = len(recall.class_ids)
 
@@ -204,6 +227,7 @@ class COCORecallTest(tf.test.TestCase):
         y_pred = tf.constant([[[0, 50, 100, 150, 1, 1.0]]], dtype=tf.float32)
         # note the low iou threshold
         metric = COCORecall(
+            bounding_box_format="xyxy",
             iou_thresholds=[0.15],
             class_ids=[1],
             area_range=(0, 10000**2),
@@ -220,6 +244,7 @@ class COCORecallTest(tf.test.TestCase):
         y_pred = tf.constant([[[0, 50, 100, 150, 1, 1.0]]], dtype=tf.float32)
         # note the low iou threshold
         metric = COCORecall(
+            bounding_box_format="xyxy",
             iou_thresholds=[0.15],
             class_ids=[1],
             area_range=(0, 10000**2),
@@ -232,11 +257,7 @@ class COCORecallTest(tf.test.TestCase):
 
     def test_true_positive_counting_one_true_two_pred(self):
         y_true = tf.constant(
-            [
-                [
-                    [0, 0, 100, 100, 1],
-                ]
-            ],
+            [[[0, 0, 100, 100, 1]]],
             dtype=tf.float32,
         )
         y_pred = tf.constant(
@@ -245,6 +266,7 @@ class COCORecallTest(tf.test.TestCase):
         )
         # note the low iou threshold
         metric = COCORecall(
+            bounding_box_format="xyxy",
             iou_thresholds=[0.15],
             class_ids=[1],
             area_range=(0, 10000**2),
@@ -264,6 +286,7 @@ class COCORecallTest(tf.test.TestCase):
         y_pred = tf.constant([[[0, 50, 100, 150, 1, 1.0]]], dtype=tf.float32)
 
         metric = COCORecall(
+            bounding_box_format="xyxy",
             iou_thresholds=[0.15],
             class_ids=[1],
             area_range=(0, 10000**2),
@@ -278,6 +301,7 @@ class COCORecallTest(tf.test.TestCase):
 
         # note the low iou threshold
         metric = COCORecall(
+            bounding_box_format="xyxy",
             iou_thresholds=[0.15],
             class_ids=[1],
             area_range=(0, 10000**2),
@@ -292,6 +316,7 @@ class COCORecallTest(tf.test.TestCase):
         y_pred = tf.constant([[[0, 50, 100, 150, 1, 1.0]]], dtype=tf.float32)
 
         metric = COCORecall(
+            bounding_box_format="xyxy",
             iou_thresholds=[0.95],
             class_ids=[1],
             area_range=(0, 100000**2),
